% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MABS_CODE.R
\name{TVS}
\alias{TVS}
\title{TVS}
\usage{
TVS(
  Y,
  X,
  selector = c("bart", "SSL"),
  topq,
  maxnrep,
  stop_crit = 100,
  fix_stop,
  niter,
  ntree,
  a = 1,
  b = 1,
  binary_reward = T
)
}
\arguments{
\item{Y}{The response, have to be continuous}

\item{X}{The matrix of variables}

\item{selector}{support BART selector 'bart' or SSLASSO selector 'SSLASSO'}

\item{topq}{An optional system. selecting variable with posterior probability greater than 0.5, we have top q variables}

\item{maxnrep}{The maximum number of iterations}

\item{stop_crit}{There is a stopping critria if the model has not changed for `stop_crit` number of times, system converge}

\item{fix_stop}{If fix stop is not missing, then the the algorithm stops after fixed number of stops}

\item{niter}{The number of MCMC iterations in BART}

\item{ntree}{The number fo trees in BART}

\item{a}{initial prior a}

\item{b}{initial prior b}

\item{binary_reward}{Whether to binarize the reward or choose a reward based on a bernoulli flip}
}
\value{
A class 'TVS' object containing the following:
\itemize{
\item `A`, `B` (The TVS A and B each row is `a_i` and `b_i` across time
\item `model_diff` is hamming distance of model at time t and time t-1
\item `time` Time taken for the algorithm to run
\item `type` either 'offline' or 'online' the type of algorithm used
}
}
\description{
This is offline TVS algorithm
}
\examples{
set.seed(2020)
#Friedman Example
X <- matrix(runif(10000),100,100)
Y <- 10 * sin(pi* X[ ,1] * X[,2]) +20 * (X[,3] -.5)^2 + 10 * X[ ,4] + 5 * X[,5] + rnorm(100,sd=1)
TVS_output <- TVS(Y,X,selector= 'bart', maxnrep = 10000, stop_crit = 100, niter = 500, ntree = 10)
posterior(TVS_output)
}
