% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MABS_STREAMING_CODE.R
\name{TVS_stream}
\alias{TVS_stream}
\title{TVS_stream
'Online' TVS which converges only after fix number of rounds \strong{and} the convergence criteria has been met}
\usage{
TVS_stream(
  Y,
  X,
  selector = "bart",
  topq,
  niter = 1000,
  ntree = 10,
  a = 1,
  b = 1,
  binary_reward = TRUE,
  batchsize,
  fix_stop,
  maxround = 100,
  stop_crit = 100
)
}
\arguments{
\item{Y}{The response, have to be continuous}

\item{X}{The matrix of variables}

\item{selector}{support BART selector 'bart' or SSLASSO selector 'SSLASSO'}

\item{topq}{An optional system. selecting variable with posterior probability greater than 0.5, we have top q variables}

\item{niter}{The number of MCMC iterations in BART}

\item{ntree}{The number fo trees in BART}

\item{a}{initial prior a}

\item{b}{initial prior b}

\item{binary_reward}{Whether to binarize the reward or choose a reward based on a bernoulli flip}

\item{batchsize}{The size of each batch}

\item{fix_stop}{If `fix_stop` is not missing, then the the algorithm stops after fixed number of stops and the stop_crit is met}

\item{maxround}{the max number of round to go through the data}

\item{stop_crit}{There is a stopping critria if the model has not changed for `stop_crit` iterations, the algorithm is deemed to reach convergence}
}
\value{
A class 'TVS' object containing the following:
\itemize{
\item `A`, `B` The TVS A and B each row is `a_i` and `b_i` across time
\item `iter_converge` The iteration number when the algorithm reach convergence
\item `round_converge` The round number when the algorithm reach convergence
\item `iter_fixed` The iteration number when the algorithm reach convergence
\item `time_fixed` Time taken for the algorithm to run fix number of rounds if fix_stop is missing, it is time taken to run one round
\item `time_converge` Time taken for the algorithm to reach convergence
\item `type` either 'offline' or 'online' the type of algorithm used, in this case 'online'
}
}
\description{
TVS_stream
'Online' TVS which converges only after fix number of rounds \strong{and} the convergence criteria has been met
}
\examples{
set.seed(2020)
X <- matrix(rnorm(1000000),10000,100)
Y <- 2 + X[,1]+ 3*X[,2] + rnorm(10000)
TVS_output <- TVS_stream(Y,X,selector= 'bart', niter= 1000, ntree = 10,
a = 1, b =1 , binary_reward = TRUE, batchsize = 500,
fix_stop = 5, maxround = 100, stop_crit =100)
posterior(TVS_output)
}
